<?php
namespace Teknisa\PED\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\ORM\DateTime;
use Teknisa\Libs\Util\DateUtil;

class Ger02400CalendarioDeDiasNaoUteisFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }
    
    public function adqPerFiliProd($CDFILIAL, $CDPERIENTR){
        try {
         
            $sql = "SELECT DISTINCT
                    PERFILPROD.CDPERIENTR, PERIENTR.IDTIPODIA
                        FROM
                        PERFILPROD, PERIENTR
                            WHERE (PERFILPROD.CDFILIAL = :CDFILIAL)
                            AND ((INSTR(:CDPERIENTR, PERFILPROD.CDPERIENTR) <> 0) OR :CDPERIENTR = 'T')
                            AND (PERFILPROD.CDPERIENTR = PERIENTR.CDPERIENTR)";

            $params = array(
                'CDFILIAL'=>$CDFILIAL,
                'CDPERIENTR'=>$CDPERIENTR
            );
            $std = $this->connection->prepare($sql);
            
            $std->execute($params);
            return $std->fetch();
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function adsRecorrente($dataSet, $adqExistsCard, $dtInicial, $nrMeses) {
        $CDFILIAL = $dataSet[2][0];
        $CDPERIPRODU = $adqExistsCard[0]["CDPERIENTR"];
        $DTINICIAL = DateUtil::truncateString($dtInicial, 'd/m/Y', 'd/m/Y h:i:s');
        $DTPROCESSA = DateUtil::truncateString($dataSet[2][2], 'd/m/Y', 'd/m/Y h:i:s');
        $NRMESES = $nrMeses;
        try {
            $this->connection->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'SEMANAL_RECORRENTE_DTENTR');
            $procedure->addParam(new Param('P_CDFILIAL',        Param::PARAM_INPUT, $CDFILIAL         ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPERIENTR',      Param::PARAM_INPUT, $CDPERIPRODU      ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINICIAL',       Param::PARAM_INPUT, $DTINICIAL        ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRMESES',         Param::PARAM_INPUT, $NRMESES          ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTPROCESSA',      Param::PARAM_INPUT, $DTPROCESSA       ,   Param::PARAM_TYPE_STR));
            $procedure->execute(); //Invoca a procedure para gerar comissão
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function adsCalcEntregas($dataSet, $adqExistsCard, $dtInicial, $nrMeses) {
        $CDFILIAL = $dataSet[2][0];
        $CDPERIPRODU = $adqExistsCard[0]["CDPERIENTR"];
        $DTINICIAL = DateUtil::truncateString($dtInicial, 'd/m/Y', 'd/m/Y h:i:s');
        $DTPROCESSA = DateUtil::truncateString($dataSet[2][2], 'd/m/Y', 'd/m/Y h:i:s');
        $NRMESES = $nrMeses;
        try {
            $this->connection->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'CALC_DATA_ENTR_MES');
            $procedure->addParam(new Param('P_CDFILIAL',        Param::PARAM_INPUT, $CDFILIAL         ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPERIENTR',      Param::PARAM_INPUT, $CDPERIPRODU      ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINICIAL',       Param::PARAM_INPUT, $DTINICIAL        ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRMESES',         Param::PARAM_INPUT, $NRMESES          ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTPROCESSA',      Param::PARAM_INPUT, $DTPROCESSA       ,   Param::PARAM_TYPE_STR));
            $procedure->execute(); //Invoca a procedure para gerar comissão
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
}