<?php
namespace Teknisa\PED\Modules\Pedidos\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\Libs\Util\Environment;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;

class Ped05000MetaVendaComissaoService{

	protected $environment;
	protected $dataSourceManager;
	protected $newCode;

    public function __construct(Environment $environment, NewCode $newCode, $dataSourceManager){
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
    }
    
    public function geraNrSeq($__new_code_pk) {
        $nrseq = $this->newCode->getCodeByTableName($__new_code_pk, $this->environment->getNrOrgTrab(), 1, 4);
        return array($nrseq, $this->environment->getNrOrgTrab());
    }
    
    public function cadastroAutomaticoVendedor($row) {
        
        $row = get_object_vars($row);
        
        $dataSource = 'metavendedor';
        $vendedor = $this->consultaVendedor($row);
        
        $vendedor = $this->removeVendedoresRepetidos($vendedor, $row);
        
        if($vendedor) {
            foreach ($vendedor as $vend) {
                
                $rowAuditoria = $this->adicionaCamposAuditoria($row);
                
                $rowInsere = array();
                $rowInsere[0] = $rowAuditoria;
                $rowInsere[0]['CDVENDEDOR'] = $vend['CDVENDEDOR'];
                
                $dataSet = new DataSet($dataSource, $rowInsere);

                try{           
                    $this->dataSourceManager->persist($dataSet);
                }
                catch(\Exception $e) {
                    throw $e;
                }

            }
        }
    }
    
    public function adicionaCamposAuditoria($row) {
        $nrorg = $this->environment->getNrorgTrab();
		$operador = $this->environment->getCdOperador();
		$currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
		$row['NRORG'] = $nrorg;
		$row['DTINCLUSAO'] = $currentTime;
		$row['DTULTATU'] = $currentTime;
		$row['CDOPERINCLUSAO'] = $operador;
		$row['CDOPERULTATU'] = $operador;
		$row['IDATIVO'] = 'S';
		$row['NRORGINCLUSAO'] = $nrorg;
		$row['NRORGULTATU'] = $nrorg;
		$row['__is_new'] = true;
		return $row;

    }
    
    public function consultaVendedor($row) {
        $dataSource = 'vendedor';
        
        $conditions = array(
	        array(
    	        "value" => $row['CDVENDEDORINI'],
    	        "operator" => ">=",
    	        "columnName" => "CDVENDEDOR"
    	    ),
	        array(
	            "value" => $row['CDVENDEDORFIM'],
	            "operator" => "<=",
    	        "columnName" => "CDVENDEDOR"
    	    )
        );

        $filterCriteria = new FilterCriteria($dataSource, $conditions);
        $result = $this->dataSourceManager->findBy($filterCriteria);
        $vendedores = $result->getRows();
        return $vendedores;
    }
    
    public function removeVendedoresRepetidos($vendedores, $row) {
        $dataSource = 'metavendedor';
        $i = 0;
        foreach ($vendedores as $vendedor) {
            $conditions = array(
    	        array(
        	        "value" => $row['CDMETAVENDA'],
        	        "operator" => "=",
        	        "columnName" => "CDMETAVENDA"
        	      ),
    	       array(
    	            "value" => $vendedor['CDVENDEDOR'],
    	            "operator" => "=",
        	        "columnName" => "CDVENDEDOR"
        	      )
            );
            $filterCriteria = new FilterCriteria($dataSource, $conditions);
            $result = $this->dataSourceManager->findBy($filterCriteria);
            if($result->getRows())  unset($vendedores[$i]);

            $i++;
        }
        return $vendedores;
    }
    
}
